/* Linux Prism II Stumbler - Utility Scan for 802_11 networks under Linux
 * 
 * File : Airjack.h
 * Project : WifiScanner (c) 2002 Herv<E9> Schauer Consultants
 * Usage : This utility is written for use with IEEE 802.11 adapters based
 * on Intersil's PRISM II chipset (PCMCIA).
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#ifndef __AIRJACK_H__
#define __AIRJACK_H__

int selectChannelAIRJACK(char *devname, int channel);
int shutCardAIRJACK(char *devname);
int openCardAIRJACK(char *devname);
int getPacketAIRJACK(unsigned char *buf, int maxlen);
int openPacketAIRJACK(char *devname);
void closePacketAIRJACK(void);

void sendDeauth(UINT8 dest[WLAN_ADDR_LEN], UINT8 bssid[WLAN_ADDR_LEN],
                UINT8 channel);

struct aj_config {
  __u16 mode;                   /* mac port operating mode */
  __u8 ownmac[6];               /* our mac address */
  __u8 monitor;                 /* are we in monitor mode */
  __u8 channel;                 /* channel to operate on... */
  __u8 essid[33];               /* first byte is length */
};

struct a3_80211 {
  union {
    __u16 fc1_frame_control;
    struct {
      __u16 fc2_version:2;
      __u16 fc2_type:2;
      __u16 fc2_subtype:4;
      __u16 fc2_to_ds:1;
      __u16 fc2_from_ds:1;
      __u16 fc2_more_frag:1;
      __u16 fc2_retry:1;
      __u16 fc2_pwr_man:1;
      __u16 fc2_more_data:1;
      __u16 fc2_wep:1;
      __u16 fc2_order:1;
    } fc2;
  } fc1;
  __u16 mh_duration_id;
  __u8 mh_mac1[6];
  __u8 mh_mac2[6];
  __u8 mh_mac3[6];
  union {
    __u16 seq1_seq;
    struct {
      __u16 seq2_frag_num:4;
      __u16 seq2_seq_num:12;
    } seq2;
  } seq1;
};

/* manefest constants to make Mac Headers more straitforward */
#define mh_fc                   fc1.fc1_frame_control
#define mh_version              fc1.fc2.fc2_version
#define mh_type                 fc1.fc2.fc2_type
#define mh_subtype              fc1.fc2.fc2_subtype
#define mh_to_ds                fc1.fc2.fc2_to_ds
#define mh_from_ds              fc1.fc2.fc2_from_ds
#define mh_more_frag    	fc1.fc2.fc2_more_frag
#define mh_retry                fc1.fc2.fc2_retry
#define mh_pwr_man              fc1.fc2.fc2_pwr_man
#define mh_more_data    	fc1.fc2.fc2_more_data
#define mh_wep                  fc1.fc2.fc2_wep
#define mh_order                fc1.fc2.fc2_order
#define mh_aid                  mh_duration_id
#define mh_ra                   mh_mac1
#define mh_da                   mh_mac1
#define mh_ps_bssid             mh_mac1
#define mh_cf_bssid             mh_mac2
#define mh_ta                   mh_mac2
#define mh_sa                   mh_mac2
#define mh_bssid                mh_mac3
#define mh_seq                  seq1.seq1_seq
#define mh_frag_num             seq1.seq2.seq2_frag_num
#define mh_seq_num              seq1.seq2.seq2_seq_num

/*** Frame Control Types ***/

#define FC_TYPE_MGT                     0x00    /* management type */
#define FC_TYPE_CTL                     0x01    /* control type */
#define FC_TYPE_DATA                    0x02    /* data type */
#define FC_TYPE_RESR                    0x03    /* reserved for later use */

/*** Management SubTypes ***/
#define MGT_AS_RQ                       0x00    /* association request */
#define MGT_AS_RS                       0x01    /* association responce */
#define MGT_REAS_RQ                     0x02    /* reassociation request */
#define MGT_REAS_RS                     0x03    /* reassociation responce */
#define MGT_PB_RQ                       0x04    /* probe request */
#define MGT_PB_RS                       0x05    /* probe responce */
#define MGT_RESERV1                     0x06
#define MGT_RESERV2                     0x07
#define MGT_BEACON                      0x08    /* beacon */
#define MGT_ATIM                        0x09    /* announcement trafic indication message */
#define MGT_DISAS                       0x0A    /* disassociation */
#define MGT_AUTH                        0x0B    /* authentication */
#define MGT_DEAUTH                      0x0C    /* de-authentication */
#define MGT_RESERV3                     0x0D
#define MGT_RESERV4                     0x0E
#define MGT_RESERV5                     0x0F

/* Airjack26 device private ioctl calls */
#define SIOCAJSMODE             SIOCDEVPRIVATE  /* so i here this probably wont work on 2.5.x, blah */
#define SIOCAJGMODE             SIOCAJSMODE + 1


#endif
